@@ -147,7 +147,7 @@ checkVersionFeasibilityWithVPN()
   # version of NVM being installed has to be same as installed VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      NVMCURRVERSION=5.1.8.105
+      NVMCURRVERSION=5.1.9.113
 
       if [ "$STANDALONE_FLAG" = true ]; then
         failed=true
@@ -174,7 +174,7 @@ checkVersionFeasibilityWithNVM()
   # version of NVM being installed has to be greater than the current NVM version
   if [ "$STANDALONE_FLAG" = true ] && [ -f ${NVMMANIFEST} ]; then
       NVMPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
-      NVMCURRVERSION=5.1.8.105
+      NVMCURRVERSION=5.1.9.113
 
       existing_ver="$(csc_vercmp "$NVMPREVVERSION" "$NVMCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -303,7 +303,7 @@ KERNELDRIVERDIR=/lib/modules/$(uname -r)/extra/cisco/
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+cisco-secure-client-linux64-5.1.8.105-nvm-install-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+cisco-secure-client-linux64-5.1.9.113-nvm-install-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco Secure Client - Network Visibility Module"
 VPNMANIFEST="${INSTPREFIX}/ACManifestVPN.xml"
 NVMMANIFEST="${INSTPREFIX}/ACManifestNVM.xml"
@@ -399,7 +399,8 @@ copyKDFFilesToNVMDir
 
 BINFILES="nvm_uninstall.sh \
           acnvmagent \
-          manifesttool_nvm"
+          manifesttool_nvm \
+          osqueryi"
 
 LIBFILES="libacruntime.so \
           libacciscossl.so \
