@@ -29,7 +29,7 @@ checkVersionFeasibilityWithStandaloneNVM()
   failed=false
   # version of VPN being installed has to be greater than the installed standalone NVM version
   if [ -f ${NVMMANIFEST} ]; then
-      VPNVERSION=5.1.8.105
+      VPNVERSION=5.1.9.113
       NVMVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
 
       vpn_ver="$(csc_vercmp "$VPNVERSION" "$NVMVERSION")"
@@ -51,7 +51,7 @@ checkInstalledVersion()
   # version of VPN being installed has to be greater than the current VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      VPNCURRVERSION=5.1.8.105
+      VPNCURRVERSION=5.1.9.113
 
       existing_ver="$(csc_vercmp "$VPNPREVVERSION" "$VPNCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -104,7 +104,7 @@ INSTALL=install
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+cisco-secure-client-linux64-5.1.8.105-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+cisco-secure-client-linux64-5.1.9.113-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco Secure Client"
 FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
@@ -246,10 +246,10 @@ if [ ! -f "%{INSTPREFIX}/update.txt" ]; then
 fi
 
 # Ensure that vpn related processes are not running. Uninstall script from older version may leave some of them alive.
-OURPROCS=`ps -A -o pid,command | grep -e "${AC_BINDIR}" -e "${BINDIR}" | egrep -v 'grep' | awk '{print $1}'`
+OURPROCS=`ps -A -o pid,command | grep -e "${AC_BINDIR}" -e "${BINDIR}" | grep -v 'grep' | awk '{print $1}'`
 if [ -n "${OURPROCS}" ] ; then
     for DOOMED in ${OURPROCS}; do
-        echo Killing `ps -A -o pid,command -p ${DOOMED} | grep ${DOOMED} | egrep -v 'ps|grep'` >> /tmp/${LOGFNAME}
+        echo Killing `ps -A -o pid,command -p ${DOOMED} | grep ${DOOMED} | grep -E -v 'ps|grep'` >> /tmp/${LOGFNAME}
         kill -KILL ${DOOMED} >> /tmp/${LOGFNAME} 2>&1
     done
 fi
